<?php
/**
* @version		mod_scorpion_imageheader.php - 21/01/2024
* @author		Edwin Witlox
* @copyright	Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
* @license		GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
* @email		info@ScorpionComputers.nl
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

// use Joomla\CMS\Helper\ModuleHelper;
require_once __DIR__ . '/lib/mod_scorpion_imageheader_helper.php';

// First we get the parameters from the module
$document = Factory::getDocument();
$baseURL = Uri::root(true);
$BGColor = $params->get( 'BGColor' );
$imagefileMain = strtok( $params->get( 'imagefileMain' ) , "#");
$imagefileMob = strtok( $params->get( 'imagefileMob' ) , "#");
$fullHeightOnMobile = $params->get( 'fullHeightOnMobile' );
$otherImageOnMobile = $params->get( 'otherImageOnMobile' );
$useEffect = $params->get( 'useEffect' );
$overlayUseFading = $params->get( 'overlayUseFading' );
$overlayUseFading2 = $params->get( 'overlayUseFading2' );
$heightOnMobile = $params->get( 'heightOnMobile', '50' );
$heightOnDesktop = $params->get( 'heightOnDesktop', '40' );
$coverImageOnDesktop = $params->get( 'coverImageOnDesktop', 'cover' );
$coverImageOnMobile = $params->get( 'coverImageOnMobile', 'cover' );
$imagePosition = $params->get( 'imagePosition', 'center' );
$useOverlay = $params->get( 'useOverlay' );
$overlayType = $params->get( 'overlayType', 'gradient' );
$useOverlay2 = $params->get( 'useOverlay2' );
$overlayType2 = $params->get( 'overlayType2', 'text' );
$overlayColor = $params->get( 'overlayColor' );
$imagefileOverlay = strtok( $params->get( 'imagefileOverlay' ) , "#");
$imagefileOverlay2 = strtok( $params->get( 'imagefileOverlay2' ) , "#");
$overlayGradientColor1 = $params->get( 'overlayGradientColor1', "#000000" );
$overlayGradientColor2 = $params->get( 'overlayGradientColor2', "#FFFFFF" );
$overlayTransparancy1 = $params->get( 'overlayTransparancy1' );
$overlayTransparancy2 = $params->get( 'overlayTransparancy2' );
$overlayGradientStart = $params->get( 'overlayGradientStart', 0 );
$overlayGradientDegrees = $params->get( 'overlayGradientDegrees', 180 );
$overlayText = $params->get( 'overlayText');
$overlayTextPosition = $params->get( 'overlayTextPosition', 'center');
$overlayText2 = $params->get( 'overlayText2');
$overlayTextPosition2 = $params->get( 'overlayTextPosition2', 'center');
$moreStyle = $params->get( 'moreStyle');
$triggerevents = $params->get( 'triggerevents');

// If the trigger events setting is true try to change the plugin parameters in the texts
if($triggerevents) {
	$overlayText = ScorpionImageHeaderHelper::ChangePluginsInContent($overlayText,$params);
	$overlayText2 = ScorpionImageHeaderHelper::ChangePluginsInContent($overlayText2,$params);
}

// Fix for update from 1.3.0 to higher version
$heightOnDesktop = str_replace(array('vh','%','px','rem','em'), '', $heightOnDesktop);
$heightOnMobile = str_replace(array('vh','%','px','rem','em'), '', $heightOnMobile);

// We first add the script and the stylesheet that belong to this module
if ($fullHeightOnMobile) {
	$heightOnMobile='100';
}

// If there is no alternative file selected for mobile, just use the main image
if (!$otherImageOnMobile) {
	$imagefileMob = $imagefileMain;
	$coverImageOnMobile = $coverImageOnDesktop;
}

// If an overlay is chosen we first have to sat some color variables to RGBA
if ($useOverlay) {
	list($r, $g, $b) = sscanf($overlayColor, "#%02x%02x%02x");
	$overlayColorRGBA = $r.",".$g.",".$b.",".$overlayTransparancy1/100;
	list($r, $g, $b) = sscanf($overlayGradientColor1, "#%02x%02x%02x");
	$overlayGradientColor1RGBA = $r.",".$g.",".$b.",".$overlayTransparancy1/100;
	list($r, $g, $b) = sscanf($overlayGradientColor2, "#%02x%02x%02x");
	$overlayGradientColor2RGBA = $r.",".$g.",".$b.",".$overlayTransparancy2/100;
}

// If no slash is at the first character of the image URL add one
// Bugfix for Joomla rendering
if($imagefileMain[0] !== '/') { $imagefileMain = '/'.$imagefileMain; }
if($imagefileMob[0] !== '/') { $imagefileMob = '/'.$imagefileMob; }
if($imagefileOverlay[0] !== '/') { $imagefileOverlay = '/'.$imagefileOverlay; }
if($imagefileOverlay2[0] !== '/') { $imagefileOverlay2 = '/'.$imagefileOverlay2; }

$effectClass = '';
if($useEffect == 1) {
	$effectClass .= ' scs-animate-fading5';
} elseif($useEffect == 2) {
	$effectClass .= ' scs-animate-grow';
}

// Add the CSS file from this module
$urlCSS = $baseURL.'/modules/mod_scorpion_imageheader/mod_scorpion_imageheader.css';
$document->addStyleSheet($urlCSS);

// We change the background color to the selected color
$extraStyle = '.scs-image-header { height:'.$heightOnDesktop.'vh !important; }'."\r\n";
$extraStyle .= '.scs-image-header .scs-image-container { background-color:'.$BGColor.' !important; }'."\r\n";
$extraStyle .= '.scs-image-header .scs-image-container { background-image: url('.$baseURL.$imagefileMain.'); }'."\r\n";
$extraStyle .= '.scs-image-header .scs-image-container { background-size: '.$coverImageOnDesktop.'vh; }'."\r\n";
$extraStyle .= '.scs-image-header .scs-image-container { background-position: '.$imagePosition.'; }'."\r\n";

// If an overlay is used we set some extra CSS here
if ($useOverlay) {
	if($overlayType === "color") {
		$extraStyle .= '.scs-image-header .scs-image-overlay { background-image: linear-gradient(180deg, rgba('.$overlayColorRGBA.') 0%, rgba('.$overlayColorRGBA.') 100%) !important; }'."\r\n";
	} else if ($overlayType === "gradient") {
		$extraStyle .= '.scs-image-header .scs-image-overlay { background-image: linear-gradient(' . $overlayGradientDegrees . 'deg, rgba('.$overlayGradientColor1RGBA.') '.$overlayGradientStart.'%, rgba('.$overlayGradientColor2RGBA.') 100%) !important; }'."\r\n";
	} else if ($overlayType === "image") {
		$extraStyle .= '.scs-image-header .scs-image-overlay { background-image: url('.$baseURL.$imagefileOverlay.'); }'."\r\n";
	} else if ($overlayType === "text") {
		$extraStyle .= '.scs-image-header .scs-image-overlay { background-image: none; }'."\r\n";
	}
}
// If we also use a second layer overlay even more CSS
if ($useOverlay2) {
	if ($overlayType2 === "image") {
		$extraStyle .= '.scs-image-header .scs-image-overlay2 { background-image: url('.$baseURL.$imagefileOverlay2.'); }'."\r\n";
	} else if ($overlayType === "text") {
		$extraStyle .= '.scs-image-header .scs-image-overlay2 { background-image: none; }'."\r\n";
	}
}

// Set extra styling specifically for mobile
$extraStyle .= '@media only screen and (max-width: 768px) {'."\r\n";
	$extraStyle .= '.scs-image-header { height:'.$heightOnMobile.'vh !important; }'."\r\n";
	$extraStyle .= '.scs-image-header .scs-image-container { background-image: url('.$baseURL.$imagefileMob.') !Important; }'."\r\n";
	$extraStyle .= '.scs-image-header .scs-image-container { background-size: '.$coverImageOnMobile.'; }'."\r\n";
$extraStyle .= '}'."\r\n"; 

// Adding style tag to the top of the HTML document for better support by browsers
// $document->addStyleDeclaration( $extraStyle ); // This would add the css in the part of the html where the module is placed
$stylelink = '<style>'."\r\n";
$stylelink .= '/* Styling for Scorpion Image Header module */'."\r\n";
$stylelink .= $extraStyle."\r\n";
$stylelink .= $moreStyle."\r\n";
$stylelink .= '</style>';
$document->addCustomTag($stylelink);

// Now we set the HTML-code that needs to be implemented for this video module
$htmlCode = "\r\n".'<!-- Scorpion Image Header - BEGIN -->'."\r\n";
$htmlCode .= '<div class="scs-image-header">'."\r\n";
$htmlCode .= '<div class="scs-image-container' . $effectClass . '"></div>'."\r\n";

if($useOverlay) {
	$overlayFadingClass = $overlayUseFading ? 'scs-animate-fading2 scs-animate-delay' : '';
	if($overlayType !== "text") { 
		$overlayText = ''; 
	} else  {
		$overlayText = '<div class="' . $overlayFadingClass . '">' . $overlayText . '</div>'."\r\n";
	}
	$htmlCode .= '<div class="scs-image-overlay row align-items-' . $overlayTextPosition . ' text-white' . $effectClass . '">' . $overlayText . '</div>'."\r\n";
}
if($useOverlay2) {
	$overlayFadingClass2 = $overlayUseFading2 ? 'scs-animate-fading2 scs-animate-delay' : '';
	if($overlayType2 !== "text") { 
		$overlayText2 = ''; 
	} else  {
		$overlayText2 = '<div class="' . $overlayFadingClass2 . '">' . $overlayText2 . '</div>'."\r\n";
	}
	$htmlCode .= '<div class="scs-image-overlay2 row align-items-' . $overlayTextPosition2 . ' text-white' . $effectClass . '">' . $overlayText2 . '</div>'."\r\n";
}
$htmlCode .= '</div>'."\r\n";
$htmlCode .='<!-- Scorpion Image Header - END -->'."\r\n";

echo $htmlCode;
// End of the code
?>
